{% extends "base.html" %}

{% block content %}
<div class="m-auto text-center">
    <h1 class="text-4xl">Check your email</h1>
    <p class="mt-4">If your email address was found, then we emailed you a link to log in.</p>
    <p class="mt-4">If you don't see it, make sure you have an account and check your spam folder.</p>
</div>
{% endblock %}
